<?php

if ( Untitled_get_value('theme', false) ) {
    register_shutdown_function(function () {
        if ($e = error_get_last()) {
            switch ($e['type']) {
                case E_ERROR:
                case E_CORE_ERROR:
                case E_COMPILE_ERROR:
                case E_PARSE:
                    printf('[PHP_ERROR]%s[PHP_ERROR]', json_encode($e));
            }
        }
    });
}

Untitled_include_theme_files();

function Untitled_include_theme_files() {
    $include_files = array('/menu/menu.php', '/menu/vmenu.php', '/search/block_form.php', '/search/block_button.php', '/search/block_input.php', '/search/theme_form.php', '/search/theme_button.php', '/search/theme_input.php', '/messages/error.php', '/messages/warning.php', '/messages/status.php', '/versions/theme_version.php');
    $include_files[] = '/versions/'.Untitled_get_major_version().'.x/theme-methods.php';
    $dirname = dirname(__FILE__);
    foreach ($include_files as $file) {
        $path = $dirname . $file;
        if (file_exists($path)) {
            require_once($path);
        }
    }
}

function Untitled_get_major_version() {
    $tok = strtok(VERSION, '.');
    return (int)$tok[0];
}

/*
 * Backward compatibility with old themes which has not set template setting
 */
function Untitled_get_backward_template($type = 'default') {
    $path = dirname(__FILE__).'/templates/templates.php';
    if (file_exists($path)) {
        require($path);
        if (isset($templates) && array_key_exists($type, $templates)) {
            foreach ($templates[$type] as $template) {
                if (isset($template['name']) && (($template['name'] == $type) ||
                    (($type == 'blog') && ($template['name'] == 'blogTemplate')))) { // blogTemplate is default name for blog type template
                    return $template['d'.Untitled_get_major_version()];
                }
            }
        }
    }
    return false;
}

function Untitled_get_templates() {
    $path = dirname(__FILE__) . '/templates/templates.php';
    if (file_exists($path)) {
        require($path);
        return $templates;
    }
    return array();
}

/*
 * Custom template with assigned filename
 * Old custom templates or first one can have no assigned filenames
 */
function Untitled_get_custom_template_filename($value) {
    $version = Untitled_get_major_version();
    $templates = Untitled_get_templates();
    if (!empty($templates) && isset($templates['customTemplate'])) {
        foreach ($templates['customTemplate'] as $customTemplate) {
            if (isset($customTemplate['custom_name_d'.$version]) && isset($customTemplate['d'.$version]) && ($value == $customTemplate['d'.$version])) {
                return $customTemplate['custom_name_d'.$version];
            }
        }
    }
    return false;
}

function Untitled_get_custom_template_urls_list_key() {
    return 'Untitled_'.Untitled_get_custom_template_url_key().'_list';
}

function Untitled_get_custom_template_url_key() {
    return 'customtemplateUrl';
}

function Untitled_get_custom_template_variable_name($url, $base_theme_name = false) {
    $name = $base_theme_name ? $base_theme_name : 'Untitled'; // to support custom templates in preview
    return $name .'_'. Untitled_get_custom_template_url_key() . '_' . preg_replace('/[^A-Za-z0-9]/', '_', $url);
}

function Untitled_get_template_key($type) {
    return 'Untitled_'.$type;
}

function Untitled_get_language($text_type = 'short') {
    global $language;
    switch ($text_type) {
        case 'full':
            return isset($language) && isset($language->name) ? $language->name : $language;
        case 'noText':
            return '';
        case 'short':
            default:
            return isset($language) && isset($language->language) ? $language->language : $language;
    }
}

function Untitled_get_direction() {
    global $language;
    return isset($language) && isset($language->dir) ? $language->dir : 'ltr';
}

if (!function_exists('render'))	{
    function render($var) {
        return $var;
    }
}

function Untitled_render_template_from_includes($file_name, $args = array(), $folder = 'includes') {
    $filePath = Untitled_normalize_path(dirname(__FILE__) .'/'. $folder . '/' . $file_name . '.php');
    include_once($filePath);
    return call_user_func_array('Untitled_'.$file_name, $args);
}

function Untitled_render_default_content($name = 'blog', $args = array(), $folder = 'includes') {
    Untitled_autoinclude(dirname(__FILE__) .'/'. $folder, $name);
    $method_name = 'Untitled_'.$name;
    if (function_exists($method_name))
        return call_user_func_array($method_name, $args);
    die('Method ' . $method_name . ' doesn\'t exist');
}

function Untitled_autoinclude($folder, $filename){
    Untitled_normalize_path($folder);

    if (!is_dir($folder)) {
        return ;
    }

    if ($handle = opendir($folder)) {
        while (($name = readdir($handle)) !== false) {
            if (strpos($name, $filename) !== false) {
                include_once($folder . '/' . $name);
            }
        }
        closedir($handle);
    }
}

function Untitled_normalize_path($path) {
    $root = ($path[0] === '/') ? '/' : '';
    $segments = preg_split('/[\\/\\\\]/', trim($path, '/'));
    $ret = array();
    foreach ($segments as $segment) {
        if (($segment == '.') || empty($segment)) {
            continue;
        }
        if ($segment == '..') {
            array_pop($ret);
        } else {
            array_push($ret, $segment);
        }
    }
    return $root . implode('/', $ret);
}

function Untitled_generate_globals($vars, $preffix = '') {
    foreach (array_keys($vars) as $key) {
        // use prefix to not overide Drupal variables
        $GLOBALS[$preffix.$key] = & $vars[$key];
    }
}

function Untitled_add_span_to_link($link) {
    $pattern = '/(.*?<a.*?>)(.*?)(<\/a>)/si';
    return preg_replace($pattern, '$1<span>$2</span>$3', $link);
}

function Untitled_has_url_param($param) {
    return !empty($_GET[$param]);
}

function Untitled_get_search_additional_class($search_block_id) {
    return strpos($search_block_id, 'block-search') !== false ? ' shape-only' : ''; // 6.x and 7.x
}

if (!function_exists('theme_get_image_path')) {
    function theme_get_image_path($image) {
        global $theme;
        $path = $GLOBALS['base_url'] . '/' . path_to_theme();
        if (Untitled_has_url_param('theme') && !file_exists(dirname(__FILE__) . '/images/' . $image)) {
            $path .= '/../' . preg_replace('/(.*)(_preview$)/', '$1', $theme);
        }

        return $path . '/images/' .$image;
    }
}

function Untitled_get_style_uri($name) {
    global $theme;
    $version = Untitled_build_version_parameter();
    $path = $GLOBALS['base_url'] . '/' . path_to_theme() . '/css/';
    $is_preview = Untitled_has_url_param('theme');
    if ($is_preview && file_exists(dirname(__FILE__) . '/css/' . $name . '.preview.php'))
        return $path . 'style.preview.php?theme=' . $theme . '&' . $version;
    if (!$is_preview && file_exists(dirname(__FILE__) . '/css/' . $name . '.min.css'))
        return $path . $name . '.min.css?' . $version;
    return $path . $name . '.css?' . $version;    
}

function Untitled_render_notemplate_content($type) {
    $notemplate = '';
    switch ($type) {
        case 'forum':
            ob_start();
?>
    <h3>Forum Template is disabled.</h3>
    <p>The Forum Template is used for <i>Forum</i> content type in Drupal.</p>
    <p>To turn on the Forum Template, please follow these steps:</p>
    <ol>
        <li><b>Create the Page</b>: In Drupal >> Content >> click "Add Content" >> choose <b>"Forum"</b>.
        <p>For <b>Drupal 6</b>: Drupal Admin menu >> Create Content >> choose <b>"Forum".</b></p>
            <ul>
                <li>Add Title, Body content.</li>
                <li>Save the Forum.</li>
            </ul>
        </li>
        <li>Back to the <b>Themler</b> >> open <b>Templates list</b> >> click <b>"Refresh"</b> or press <b>F5</b>.</li>
    </ol>
<?php
            $notemplate = ob_get_clean();
            break;
        case 'page':
            ob_start();
?>
    <h3>Page Template is disabled.</h3>
    <p>The Page Template is used for <i>Basic Page</i> content type in Drupal.</p>
    <p>To turn on the Page Template, please follow these steps:</p>
    <ol>
        <li><b>Create the Page</b>: In Drupal >> Content >> click "Add Content" >> choose <b>"Basic Page"</b>.
        <p>For <b>Drupal 6</b>: Drupal Admin menu >> Create Content >> choose <b>"Page".</b></p>
            <ul>
                <li>Add Title, Body content.</li>
                <li>Save the Page.</li>
            </ul>
        </li>
        <li>Back to the <b>Themler</b> >> open <b>Templates list</b> >> click <b>"Refresh"</b> or press <b>F5</b>.</li>
    </ol>
<?php
            $notemplate = ob_get_clean();
            break;

        case 'story':
        case 'article':
             ob_start();
?>
    <h3>Post Template is disabled.</h3>
    <p>The Post Template is used for <i>Article</i> content type in Drupal.</p>

    <p>To turn on the Post Template, please follow these steps:</p>
    <ol>
        <li><b>Create an Article</b>: In Drupal >> Content >> click "Add Content" >> choose <b>"Article"</b>.
        <p>For <b>Drupal 6</b>: Drupal Admin menu >> Create Content >> choose <b>"Story".</b></p>
            <ul>
                <li>Add Title, Body content.</li>
                <li>Save the Article.</li>
            </ul>
        </li>
        <li>Back to the <b>Themler</b> >> open <b>Templates list</b> >> click <b>"Refresh"</b> or press <b>F5</b>.</li>
    </ol>
<?php
            $notemplate = ob_get_clean();
            break;
        default: // TODO: add custom templates nopage here
            break;
    }

    ob_start();
?>
<style>
    html {
        margin-top: 30px !important;
    }
    body {
        font-family: inherit;
        color:#000000;
        background-color: #FFFFFF;
    }
    .jumbotron {
        background-color: #EEEEEE;
        border-radius: 6px 6px 6px 6px;
        color: inherit;
        font-size: 16px;
        font-weight: 200;
        line-height: 27px;
        margin-bottom: 30px;
        padding: 60px;
    }
    .jumbotron li {
        line-height: 27px;
        white-space: normal;
    }
</style>
<div class="container">
    <div class="jumbotron">
        <?php print render($notemplate); ?>
    </div>
</div>
<?php 
    $content = ob_get_clean();
    return $content;
}

function Untitled_get_value($key, $default_value = false) {
    if (!isset($key) || empty($key) || !is_string($key))
        return false;
    $ret = (isset($_POST[$key]) ? $_POST[$key] : (isset($_GET[$key]) ? $_GET[$key] : $default_value));

    if (is_string($ret) === true)
        $ret = urldecode(preg_replace('/((\%5C0+)|(\%00+))/i', '', urlencode($ret)));
    return !is_string($ret)? $ret : stripslashes($ret);
}

function Untitled_get_predefined_template($node_type) {
    if (Untitled_EXPORT_VERSION > 6) { // drupal 7
        $result = db_select('node_type', 'n')->fields('n',array('orig_type'))->condition('type', $node_type,'=')->execute()->fetchAssoc();
        $orig_type = $result && isset($result['orig_type']) ? $result['orig_type'] : false;
    } else {
        $orig_type = db_result(db_query("SELECT node_type.orig_type FROM {node_type} WHERE type = '%s'", $node_type));
    }
    switch ($orig_type) {
        case 'article':
        case 'story':
            $type = 'singlePostTemplate';
            break;
        case 'page':
            $type = 'pageTemplate';
            break;
        case 'forum':
            $type = 'forumTemplate';
            break;
        default:
            $type = false;
            break;
    }
    return $type;
}